package org.itqop.chatit.handlers;

import net.minecraftforge.eventbus.api.SubscribeEvent;
import net.minecraftforge.event.ServerChatEvent;
import net.minecraftforge.fml.common.Mod;
import net.minecraft.server.level.ServerPlayer;
import net.minecraft.network.chat.Component;
import net.minecraft.network.chat.MutableComponent;
import net.minecraft.server.MinecraftServer;
import net.minecraft.ChatFormatting;
import org.itqop.chatit.utils.Config;
import org.itqop.chatit.utils.PlayerConfigManager;
import org.itqop.chatit.utils.ProfanityChecker;
import org.slf4j.Logger;
import com.mojang.logging.LogUtils;

import java.util.concurrent.CompletableFuture;

@Mod.EventBusSubscriber
public class ChatEventHandler {

    private static final Logger LOGGER = LogUtils.getLogger();

    @SubscribeEvent
    public static void onServerChat(ServerChatEvent event) {
        ServerPlayer sender = event.getPlayer();

        MinecraftServer server = sender.getServer();
        String originalMessage = event.getMessage().getString();

        event.setCanceled(true);

        PlayerConfigManager.ensurePlayerExists(sender);

        boolean isGlobal = originalMessage.startsWith("!");
        String message = isGlobal ? originalMessage.substring(1) : originalMessage;

        MutableComponent chatComponent = createChatMessage(sender, message, isGlobal);

        CompletableFuture<Double> future = ProfanityChecker.checkMessageAsync(message);

        future.thenAccept(profanityScore -> {
            if (server != null) {
                server.execute(() -> {
                    double threshold = Config.profanityThreshold; // Получаем порог из конфигурации

                    if (profanityScore > threshold && !PlayerConfigManager.hasAdultContentEnabled(sender)) {
                        MutableComponent errorComponent = createErrorMessage(sender, message);
                        sender.sendSystemMessage(errorComponent);
                    } else {
                        for (ServerPlayer receiver : server.getPlayerList().getPlayers()) {
                            PlayerConfigManager.ensurePlayerExists(receiver);

                            if (profanityScore > threshold && !PlayerConfigManager.hasAdultContentEnabled(receiver)) {
                                continue;
                            }
                            if (isGlobal || (receiver.getCommandSenderWorld() == sender.getCommandSenderWorld() && receiver.position().distanceTo(sender.position()) <= 50)) {
                                receiver.sendSystemMessage(chatComponent);
                            }
                        }
                    }
                });
            }
        }).exceptionally(ex -> {
            LOGGER.error(ex.toString());
            if (server != null) {
                server.execute(() -> {
                    MutableComponent errorComponent = createErrorMessage(sender, message);
                    sender.sendSystemMessage(errorComponent);
                });
            }
            return null;
        });
    }

    private static MutableComponent createErrorMessage(ServerPlayer player, String message) {
        MutableComponent openBracket = Component.literal("[");
        MutableComponent errorText = Component.literal("ERROR")
                .withStyle(ChatFormatting.RED);
        MutableComponent closeBracket = Component.literal("] ");

        MutableComponent prefixComponent = openBracket.append(errorText).append(closeBracket);

        Component playerName = Component.literal(player.getName().getString());
        Component messageComponent = Component.literal(": " + message);

        return prefixComponent.append(playerName).append(messageComponent);
    }

    private static MutableComponent createChatMessage(ServerPlayer player, String message, boolean isGlobal) {
        MutableComponent openBracket = Component.literal("[");
        MutableComponent letterComponent;
        MutableComponent closeBracket = Component.literal("] ");

        if (isGlobal) {
            letterComponent = Component.literal("G")
                    .withStyle(ChatFormatting.GREEN);
        } else {
            letterComponent = Component.literal("L")
                    .withStyle(ChatFormatting.YELLOW);
        }

        MutableComponent prefixComponent = openBracket.append(letterComponent).append(closeBracket);

        Component playerName = Component.literal(player.getName().getString());
        Component messageComponent = Component.literal(": " + message);

        return prefixComponent.append(playerName).append(messageComponent);
    }
}
