package org.itqop.chatit.utils;

import com.google.gson.Gson;
import com.google.gson.reflect.TypeToken;
import net.minecraft.server.level.ServerPlayer;

import java.io.File;
import java.io.FileReader;
import java.io.FileWriter;
import java.lang.reflect.Type;
import java.util.HashMap;
import java.util.Map;
import java.util.UUID;

import org.slf4j.Logger;
import com.mojang.logging.LogUtils;

public class PlayerConfigManager {

    private static final Gson GSON = new Gson();
    private static final File CONFIG_FILE = new File("config/chatit_player_settings.json");
    private static final Type CONFIG_TYPE = new TypeToken<Map<UUID, Boolean>>() {}.getType();
    private static final Logger LOGGER = LogUtils.getLogger();

    private static Map<UUID, Boolean> playerSettings = new HashMap<>();

    public static void loadConfig() {
        if (CONFIG_FILE.exists()) {
            try (FileReader reader = new FileReader(CONFIG_FILE)) {
                playerSettings = GSON.fromJson(reader, CONFIG_TYPE);
            } catch (Exception e) {
                LOGGER.error(e.toString());
            }
        }
    }

    public static void saveConfig() {
        try (FileWriter writer = new FileWriter(CONFIG_FILE)) {
            GSON.toJson(playerSettings, writer);
        } catch (Exception e) {
            LOGGER.error(e.toString());
        }
    }

    public static boolean hasAdultContentEnabled(ServerPlayer player) {
        return playerSettings.getOrDefault(player.getUUID(), Config.defaultAdult);
    }

    public static void toggleAdultContent(ServerPlayer player) {
        boolean current = hasAdultContentEnabled(player);
        playerSettings.put(player.getUUID(), !current);
        saveConfig();
    }

    public static void ensurePlayerExists(ServerPlayer player) {
        if (!playerSettings.containsKey(player.getUUID())) {
            playerSettings.put(player.getUUID(), Config.defaultAdult);
            saveConfig();
        }
    }
}
